### The scanner of words on the command line

sub new {
  my $class = shift;

  $self = { printer => Printer->new, };

  bless $self, $class;
}

sub scanLine {
  my $self = shift;

  $self->{printer}->printPrompt;
  my $line = readline;
  
  return $line;
}

1;
